@@ -5,7 +5,7 @@ use warnings;
 
 use 5.008;
 
-use vars qw($VERSION @ISA);
+use vars qw(@ISA);
 require DynaLoader;
 
 @ISA = qw(DynaLoader);
@@ -14,7 +14,7 @@ require DynaLoader;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-$VERSION = '1.32';
+our $VERSION = '1.33';
 
 bootstrap Math::FFT $VERSION;
 
@@ -604,7 +604,7 @@ Math::FFT - Perl module to calculate Fast Fourier Transforms
 
 =head1 VERSION
 
-version 1.32
+version 1.33
 
 =head1 SYNOPSIS
 
@@ -725,7 +725,7 @@ C<$orig_data> coincides with the original C<$data>.
 
 =item C<$coeff = $fft-E<gt>ddct();>
 
-Computes the discrete cosine tranform on a data set
+Computes the discrete cosine transform on a data set
 C<data[0...n-1]> contained in an array reference C<$data>. An
 array reference C<$coeff> is returned consisting of
 
@@ -737,7 +737,7 @@ where
 
 =item C<$orig_data = $fft-E<gt>invddct([$coeff]);>
 
-Computes the inverse discrete cosine tranform on a data set
+Computes the inverse discrete cosine transform on a data set
 C<coeff[0...n-1]> contained in an array reference C<$coeff>.
 If C<$coeff> is not given, it will be set equal to an earlier
 call to C<$fft-E<gt>ddct()>. An array reference C<$orig_data>
@@ -1178,8 +1178,8 @@ the same terms as the Perl 5 programming language system itself.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://rt.cpan.org/Public/Dist/Display.html?Name=Math-FFT or by email to
-bug-math-fft@rt.cpan.org.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Math-FFT> or by email
+to L<bug-math-fft@rt.cpan.org|mailto:bug-math-fft@rt.cpan.org>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -1224,7 +1224,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Math-FFT>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Math-FFT>
 
 =item *
 
@@ -1256,7 +1256,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Math-FFT>
+L<http://cpants.cpanauthors.org/dist/Math-FFT>
 
 =item *
 
@@ -1287,7 +1287,7 @@ L<http://deps.cpantesters.org/?module=Math::FFT>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-math-fft at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Math-FFT>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Math-FFT>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
